@@ -26,13 +26,16 @@
 
 class QSMSMessage;
 class QVMMessage;
+class SimRules;
 class HardwareManipulator : public QObject
 {
 Q_OBJECT
 
 public:
-    HardwareManipulator(QObject *parent=0);
+    HardwareManipulator(SimRules *sr, QObject *parent=0);
     QSMSMessageList & getSMSList();
+    bool getSimPresent();
+    QString getSimAppName();
 
 public slots:
     virtual void handleFromData( const QString& );
@@ -41,6 +44,11 @@ public slots:
     virtual void constructSMSMessage(const int type, const QString &sender, const QString &serviceCenter, const QString &text);
     virtual void sendSMS( const QSMSMessage& m );
     virtual void sendVMNotify( int type, int count, const QList<QVMMessage> &received, const QList<QVMMessage> &deleted, const QString &mailbox );
+    virtual void sendUSSD( bool cancel, bool response, const QString &content );
+    virtual void setSimPresent( bool present );
+    virtual void simAppStart();
+    virtual void simAppAbort();
+    virtual void handleNewApp();
 
 signals:
     void unsolicitedCommand(const QString &cmd);
@@ -52,7 +60,7 @@ signals:
 protected:
     virtual QString constructCBMessage(const QString &messageCode, int geographicalScope, const QString &updateNumber, const QString &channel,
     const QString &scheme, int language, const QString &numPages, const QString &page, const QString &content);
-    virtual void constructSMSDatagram(int port, const QString &sender,  const QByteArray &data, const QByteArray &contentType);
+    virtual void constructSMSDatagram(int src, int dst, const QString &sender,  const QByteArray &data, const QByteArray &contentType);
 
     virtual void warning(const QString &title, const QString &message);
 
@@ -60,14 +68,16 @@ protected:
 
 private:
     QSMSMessageList SMSList;
+    SimRules *rules;
+    bool simPresent;
 };
 
 class HardwareManipulatorFactory
 {
 public:
     virtual ~HardwareManipulatorFactory() {};
-    inline virtual HardwareManipulator *create(QObject *p)
-	    { return new HardwareManipulator(p); }
+    inline virtual HardwareManipulator *create(SimRules *sr, QObject *p)
+	    { return new HardwareManipulator(sr, p); }
 
     QString ruleFile() const { return ruleFilename; }
     void setRuleFile(const QString& filename) { ruleFilename = filename; }
